@@ -11,8 +11,12 @@ from torch.utils._pytree import tree_map, tree_flatten, tree_unflatten
 
 
 ODict = OrderedDict
-Permutations = List[Tuple[str, ...]]
-MappedPermutations = List[Tuple[int, ...]]
+
+Permutation = List[Tuple[str, ...]]
+MappedPermutation = List[Tuple[int, ...]]
+
+Permutations = List[Permutation]
+MappedPermutations = List[MappedPermutation]
 
 PermutationGroup = List[List[int]]
 SymbolicPermutationGroup = sympy.combinatorics.PermutationGroup
@@ -154,6 +158,7 @@ class Batch(NamedTuple):
 class Outputs(NamedTuple):
     assignments: List[Tensor]
     detections: List[Tensor]
+    vectors: Dict[str, Tensor]
     regressions: Dict[str, Tensor]
     classifications: Dict[str, Tensor]
 
