@@ -1,5 +1,3 @@
-from torch import jit
-
 from spanet.options import Options
 
 from spanet.network.layers.transformer.transformer_base import TransformerBase
@@ -16,15 +14,15 @@ def create_transformer(
     transformer_type = transformer_type.lower().replace("_", "").replace(" ", "")
 
     if num_layers <= 0:
-        return jit.script(TransformerBase(options, num_layers))
+        return TransformerBase(options, num_layers)
 
     if transformer_type == "standard":
-        return jit.script(StandardTransformer(options, num_layers))
+        return StandardTransformer(options, num_layers)
     elif transformer_type == 'normfirst':
-        return jit.script(NormFirstTransformer(options, num_layers))
+        return NormFirstTransformer(options, num_layers)
     elif transformer_type == 'gated':
-        return jit.script(GatedTransformer(options, num_layers))
+        return GatedTransformer(options, num_layers)
     elif transformer_type == 'gtrxl':
-        return jit.script(GatedTransformer(options, num_layers))
+        return GatedTransformer(options, num_layers)
     else:
-        return jit.script(TransformerBase(options, num_layers))
+        return TransformerBase(options, num_layers)
